pub struct Input {
pub name: FHIRString,
pub concept: Option<Vec<Coding>>,
pub version: Option<FHIRString>,
}Fields
name: FHIRStringThe name that defines the particular context for the subsumption based closure table
concept: Option<Vec<Coding>>Concepts to add to the closure table
version: Option<FHIRString>A request to resynchronise - request to send all new entries since the nominated version was sent by the server